@@ -1,14 +1,12 @@
 use super::*;
-use crate::tests::HygieneVisualizer;
-use crate::tests::Tester;
-use std::collections::HashMap;
-use swc_common::{hygiene::*, DUMMY_SP};
+use crate::tests::{HygieneVisualizer, Tester};
+use swc_common::{collections::AHashMap, hygiene::*, DUMMY_SP};
 use swc_ecma_parser::Syntax;
 use swc_ecma_utils::quote_ident;
 use swc_ecma_visit::{Fold, FoldWith};
 
 struct Marker {
-    map: HashMap<JsWord, Mark>,
+    map: AHashMap<JsWord, Mark>,
 }
 
 fn marker(markers: &[(&str, Mark)]) -> Marker {
@@ -28,7 +26,7 @@ impl Fold for Marker {
 }
 
 struct OnceMarker {
-    map: HashMap<JsWord, Vec<Mark>>,
+    map: AHashMap<JsWord, Vec<Mark>>,
 }
 
 impl OnceMarker {
